Class: Google::Apis::ContentV2_1::ProductStatusItemLevelIssue
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::ProductStatusItemLevelIssue
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Instance Attribute Summary collapse
-
#applicable_countries ⇒ Array<String>
List of country codes (ISO 3166-1 alpha-2) where issue applies to the offer.
-
#attribute_name ⇒ String
The attribute's name, if the issue is caused by a single attribute.
-
#code ⇒ String
The error code of the issue.
-
#description ⇒ String
A short issue description in English.
-
#destination ⇒ String
The destination the issue applies to.
-
#detail ⇒ String
A detailed issue description in English.
-
#documentation ⇒ String
The URL of a web page to help with resolving this issue.
-
#resolution ⇒ String
Whether the issue can be resolved by the merchant.
-
#servability ⇒ String
How this issue affects serving of the offer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductStatusItemLevelIssue
constructor
A new instance of ProductStatusItemLevelIssue.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductStatusItemLevelIssue
Returns a new instance of ProductStatusItemLevelIssue.
10159 10160 10161 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10159 def initialize(**args) update!(**args) end |
Instance Attribute Details
#applicable_countries ⇒ Array<String>
List of country codes (ISO 3166-1 alpha-2) where issue applies to the offer.
Corresponds to the JSON property applicableCountries
10117 10118 10119 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10117 def applicable_countries @applicable_countries end |
#attribute_name ⇒ String
The attribute's name, if the issue is caused by a single attribute.
Corresponds to the JSON property attributeName
10122 10123 10124 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10122 def attribute_name @attribute_name end |
#code ⇒ String
The error code of the issue.
Corresponds to the JSON property code
10127 10128 10129 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10127 def code @code end |
#description ⇒ String
A short issue description in English.
Corresponds to the JSON property description
10132 10133 10134 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10132 def description @description end |
#destination ⇒ String
The destination the issue applies to.
Corresponds to the JSON property destination
10137 10138 10139 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10137 def destination @destination end |
#detail ⇒ String
A detailed issue description in English.
Corresponds to the JSON property detail
10142 10143 10144 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10142 def detail @detail end |
#documentation ⇒ String
The URL of a web page to help with resolving this issue.
Corresponds to the JSON property documentation
10147 10148 10149 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10147 def documentation @documentation end |
#resolution ⇒ String
Whether the issue can be resolved by the merchant.
Corresponds to the JSON property resolution
10152 10153 10154 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10152 def resolution @resolution end |
#servability ⇒ String
How this issue affects serving of the offer.
Corresponds to the JSON property servability
10157 10158 10159 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10157 def servability @servability end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10164 10165 10166 10167 10168 10169 10170 10171 10172 10173 10174 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10164 def update!(**args) @applicable_countries = args[:applicable_countries] if args.key?(:applicable_countries) @attribute_name = args[:attribute_name] if args.key?(:attribute_name) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) @destination = args[:destination] if args.key?(:destination) @detail = args[:detail] if args.key?(:detail) @documentation = args[:documentation] if args.key?(:documentation) @resolution = args[:resolution] if args.key?(:resolution) @servability = args[:servability] if args.key?(:servability) end |