Class: Google::Apis::ContentV2_1::ProductstatusesCustomBatchRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::ProductstatusesCustomBatchRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Instance Attribute Summary collapse
-
#entries ⇒ Array<Google::Apis::ContentV2_1::ProductstatusesCustomBatchRequestEntry>
The request entries to be processed in the batch.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductstatusesCustomBatchRequest
constructor
A new instance of ProductstatusesCustomBatchRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductstatusesCustomBatchRequest
Returns a new instance of ProductstatusesCustomBatchRequest.
10948 10949 10950 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10948 def initialize(**args) update!(**args) end |
Instance Attribute Details
#entries ⇒ Array<Google::Apis::ContentV2_1::ProductstatusesCustomBatchRequestEntry>
The request entries to be processed in the batch.
Corresponds to the JSON property entries
10946 10947 10948 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10946 def entries @entries end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10953 10954 10955 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10953 def update!(**args) @entries = args[:entries] if args.key?(:entries) end |