Class: Google::Apis::ContentV2_1::RegionalInventory

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb

Overview

Regional inventory resource. contains the regional name and all attributes which are overridden for the specified region.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RegionalInventory

Returns a new instance of RegionalInventory.



11973
11974
11975
# File 'lib/google/apis/content_v2_1/classes.rb', line 11973

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#availabilityString

The availability of the product. Corresponds to the JSON property availability

Returns:

  • (String)


11937
11938
11939
# File 'lib/google/apis/content_v2_1/classes.rb', line 11937

def availability
  @availability
end

#custom_attributesArray<Google::Apis::ContentV2_1::CustomAttribute>

A list of custom (merchant-provided) attributes. It can also be used for submitting any attribute of the feed specification in its generic form. Corresponds to the JSON property customAttributes



11943
11944
11945
# File 'lib/google/apis/content_v2_1/classes.rb', line 11943

def custom_attributes
  @custom_attributes
end

#kindString

Identifies what kind of resource this is. Value: the fixed string "content# regionalInventory". Corresponds to the JSON property kind

Returns:

  • (String)


11949
11950
11951
# File 'lib/google/apis/content_v2_1/classes.rb', line 11949

def kind
  @kind
end

#priceGoogle::Apis::ContentV2_1::Price

The price of the product. Corresponds to the JSON property price



11954
11955
11956
# File 'lib/google/apis/content_v2_1/classes.rb', line 11954

def price
  @price
end

#region_idString

The ID uniquely identifying each region. Corresponds to the JSON property regionId

Returns:

  • (String)


11959
11960
11961
# File 'lib/google/apis/content_v2_1/classes.rb', line 11959

def region_id
  @region_id
end

#sale_priceGoogle::Apis::ContentV2_1::Price

The sale price of the product. Mandatory if sale_price_effective_date is defined. Corresponds to the JSON property salePrice



11965
11966
11967
# File 'lib/google/apis/content_v2_1/classes.rb', line 11965

def sale_price
  @sale_price
end

#sale_price_effective_dateString

A date range represented by a pair of ISO 8601 dates separated by a space, comma, or slash. Both dates might be specified as 'null' if undecided. Corresponds to the JSON property salePriceEffectiveDate

Returns:

  • (String)


11971
11972
11973
# File 'lib/google/apis/content_v2_1/classes.rb', line 11971

def sale_price_effective_date
  @sale_price_effective_date
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



11978
11979
11980
11981
11982
11983
11984
11985
11986
# File 'lib/google/apis/content_v2_1/classes.rb', line 11978

def update!(**args)
  @availability = args[:availability] if args.key?(:availability)
  @custom_attributes = args[:custom_attributes] if args.key?(:custom_attributes)
  @kind = args[:kind] if args.key?(:kind)
  @price = args[:price] if args.key?(:price)
  @region_id = args[:region_id] if args.key?(:region_id)
  @sale_price = args[:sale_price] if args.key?(:sale_price)
  @sale_price_effective_date = args[:sale_price_effective_date] if args.key?(:sale_price_effective_date)
end