Class: Google::Apis::ContentV2_1::RenderProductIssuesRequestPayload
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::RenderProductIssuesRequestPayload
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
The payload for configuring how the content should be rendered.
Instance Attribute Summary collapse
-
#content_option ⇒ String
Optional.
-
#user_input_action_option ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RenderProductIssuesRequestPayload
constructor
A new instance of RenderProductIssuesRequestPayload.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RenderProductIssuesRequestPayload
Returns a new instance of RenderProductIssuesRequestPayload.
12192 12193 12194 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#content_option ⇒ String
Optional. How the detailed content should be returned. Default option is to
return the content as a pre-rendered HTML text.
Corresponds to the JSON property contentOption
12183 12184 12185 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12183 def content_option @content_option end |
#user_input_action_option ⇒ String
Optional. How actions with user input form should be handled. If not provided,
actions will be returned as links that points merchant to Merchant Center
where they can request the action.
Corresponds to the JSON property userInputActionOption
12190 12191 12192 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12190 def user_input_action_option @user_input_action_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12197 12198 12199 12200 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12197 def update!(**args) @content_option = args[:content_option] if args.key?(:content_option) @user_input_action_option = args[:user_input_action_option] if args.key?(:user_input_action_option) end |