Class: Google::Apis::ContentV2_1::ReportRow

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb

Overview

Result row returned from the search query.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportRow

Returns a new instance of ReportRow.



12354
12355
12356
# File 'lib/google/apis/content_v2_1/classes.rb', line 12354

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#best_sellersGoogle::Apis::ContentV2_1::BestSellers

Fields related to the Best sellers reports. Corresponds to the JSON property bestSellers



12283
12284
12285
# File 'lib/google/apis/content_v2_1/classes.rb', line 12283

def best_sellers
  @best_sellers
end

#brandGoogle::Apis::ContentV2_1::Brand

Brand fields. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property brand



12289
12290
12291
# File 'lib/google/apis/content_v2_1/classes.rb', line 12289

def brand
  @brand
end

#competitive_visibilityGoogle::Apis::ContentV2_1::CompetitiveVisibility

Fields related to competitive visibility reports. Corresponds to the JSON property competitiveVisibility



12295
12296
12297
# File 'lib/google/apis/content_v2_1/classes.rb', line 12295

def competitive_visibility
  @competitive_visibility
end

#metricsGoogle::Apis::ContentV2_1::Metrics

Performance metrics. Values are only set for metrics requested explicitly in the request's search query. Corresponds to the JSON property metrics



12301
12302
12303
# File 'lib/google/apis/content_v2_1/classes.rb', line 12301

def metrics
  @metrics
end

#price_competitivenessGoogle::Apis::ContentV2_1::PriceCompetitiveness

Price competitiveness fields requested by the merchant in the query. Field values are only set if the merchant queries PriceCompetitivenessProductView. https://support.google.com/merchants/answer/9626903 Corresponds to the JSON property priceCompetitiveness



12308
12309
12310
# File 'lib/google/apis/content_v2_1/classes.rb', line 12308

def price_competitiveness
  @price_competitiveness
end

#price_insightsGoogle::Apis::ContentV2_1::PriceInsights

Price insights fields requested by the merchant in the query. Field values are only set if the merchant queries PriceInsightsProductView. https://support. google.com/merchants/answer/11916926 Corresponds to the JSON property priceInsights



12315
12316
12317
# File 'lib/google/apis/content_v2_1/classes.rb', line 12315

def price_insights
  @price_insights
end

#product_clusterGoogle::Apis::ContentV2_1::ProductCluster

Product cluster fields. A product cluster is a grouping for different offers that represent the same product. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property productCluster



12322
12323
12324
# File 'lib/google/apis/content_v2_1/classes.rb', line 12322

def product_cluster
  @product_cluster
end

#product_viewGoogle::Apis::ContentV2_1::ProductView

Product fields. Values are only set for fields requested explicitly in the request's search query. Corresponds to the JSON property productView



12328
12329
12330
# File 'lib/google/apis/content_v2_1/classes.rb', line 12328

def product_view
  @product_view
end

#segmentsGoogle::Apis::ContentV2_1::Segments

Dimensions according to which metrics are segmented in the response. Values of product dimensions, such as offer_id, reflect the state of a product at the time of the corresponding event, for example, impression or order. Segment fields cannot be selected in queries without also selecting at least one metric field. Values are only set for dimensions requested explicitly in the request's search query. Corresponds to the JSON property segments



12338
12339
12340
# File 'lib/google/apis/content_v2_1/classes.rb', line 12338

def segments
  @segments
end

Topic trends fields requested by the merchant in the query. Field values are only set if the merchant queries TopicTrendsView. Forecast data can be queried up to 13 weeks by passing a future date in the date field. Historical data is measured daily, and forecasted data is projected weekly. All data points are normalized based on the highest data points returned in the response. If you make separate queries with different date ranges, you might see different values for the same date in each response. The recommended way to get a trend score of a topic is last7_days_search_interest / last$day _days_search_interest - 1. You can view trends for up to eight topics at a time. Corresponds to the JSON property topicTrends



12352
12353
12354
# File 'lib/google/apis/content_v2_1/classes.rb', line 12352

def topic_trends
  @topic_trends
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



12359
12360
12361
12362
12363
12364
12365
12366
12367
12368
12369
12370
# File 'lib/google/apis/content_v2_1/classes.rb', line 12359

def update!(**args)
  @best_sellers = args[:best_sellers] if args.key?(:best_sellers)
  @brand = args[:brand] if args.key?(:brand)
  @competitive_visibility = args[:competitive_visibility] if args.key?(:competitive_visibility)
  @metrics = args[:metrics] if args.key?(:metrics)
  @price_competitiveness = args[:price_competitiveness] if args.key?(:price_competitiveness)
  @price_insights = args[:price_insights] if args.key?(:price_insights)
  @product_cluster = args[:product_cluster] if args.key?(:product_cluster)
  @product_view = args[:product_view] if args.key?(:product_view)
  @segments = args[:segments] if args.key?(:segments)
  @topic_trends = args[:topic_trends] if args.key?(:topic_trends)
end