Class: Google::Apis::ContentV2_1::Service

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Service

Returns a new instance of Service.



13025
13026
13027
# File 'lib/google/apis/content_v2_1/classes.rb', line 13025

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activeBoolean Also known as: active?

A boolean exposing the active status of the shipping service. Required. Corresponds to the JSON property active

Returns:

  • (Boolean)


12954
12955
12956
# File 'lib/google/apis/content_v2_1/classes.rb', line 12954

def active
  @active
end

#currencyString

The CLDR code of the currency to which this service applies. Must match that of the prices in rate groups. Corresponds to the JSON property currency

Returns:

  • (String)


12961
12962
12963
# File 'lib/google/apis/content_v2_1/classes.rb', line 12961

def currency
  @currency
end

#delivery_countryString

The CLDR territory code of the country to which the service applies. Required. Corresponds to the JSON property deliveryCountry

Returns:

  • (String)


12966
12967
12968
# File 'lib/google/apis/content_v2_1/classes.rb', line 12966

def delivery_country
  @delivery_country
end

#delivery_timeGoogle::Apis::ContentV2_1::DeliveryTime

Time spent in various aspects from order to the delivery of the product. Required. Corresponds to the JSON property deliveryTime



12972
12973
12974
# File 'lib/google/apis/content_v2_1/classes.rb', line 12972

def delivery_time
  @delivery_time
end

#eligibilityString

Eligibility for this service. Acceptable values are: - "All scenarios" - " All scenarios except Shopping Actions" - "Shopping Actions" Corresponds to the JSON property eligibility

Returns:

  • (String)


12978
12979
12980
# File 'lib/google/apis/content_v2_1/classes.rb', line 12978

def eligibility
  @eligibility
end

#minimum_order_valueGoogle::Apis::ContentV2_1::Price

Minimum order value for this service. If set, indicates that customers will have to spend at least this amount. All prices within a service must have the same currency. Cannot be set together with minimum_order_value_table. Corresponds to the JSON property minimumOrderValue



12985
12986
12987
# File 'lib/google/apis/content_v2_1/classes.rb', line 12985

def minimum_order_value
  @minimum_order_value
end

#minimum_order_value_tableGoogle::Apis::ContentV2_1::MinimumOrderValueTable

Table of per store minimum order values for the pickup fulfillment type. Cannot be set together with minimum_order_value. Corresponds to the JSON property minimumOrderValueTable



12991
12992
12993
# File 'lib/google/apis/content_v2_1/classes.rb', line 12991

def minimum_order_value_table
  @minimum_order_value_table
end

#nameString

Free-form name of the service. Must be unique within target account. Required. Corresponds to the JSON property name

Returns:

  • (String)


12996
12997
12998
# File 'lib/google/apis/content_v2_1/classes.rb', line 12996

def name
  @name
end

#pickup_serviceGoogle::Apis::ContentV2_1::PickupCarrierService

The carrier-service pair delivering items to collection points. The list of supported pickup services can be retrieved through the getSupportedPickupServices method. Required if and only if the service delivery type is pickup. Corresponds to the JSON property pickupService



13004
13005
13006
# File 'lib/google/apis/content_v2_1/classes.rb', line 13004

def pickup_service
  @pickup_service
end

#rate_groupsArray<Google::Apis::ContentV2_1::RateGroup>

Shipping rate group definitions. Only the last one is allowed to have an empty applicableShippingLabels, which means "everything else". The other applicableShippingLabels must not overlap. Corresponds to the JSON property rateGroups



13011
13012
13013
# File 'lib/google/apis/content_v2_1/classes.rb', line 13011

def rate_groups
  @rate_groups
end

#shipment_typeString

Type of locations this service ships orders to. Acceptable values are: - " delivery" - "pickup (deprecated)" - "local_delivery" - "collection_point " Corresponds to the JSON property shipmentType

Returns:

  • (String)


13018
13019
13020
# File 'lib/google/apis/content_v2_1/classes.rb', line 13018

def shipment_type
  @shipment_type
end

#store_configGoogle::Apis::ContentV2_1::ServiceStoreConfig

Stores that provide local delivery. Only valid with local delivery fulfillment. Corresponds to the JSON property storeConfig



13023
13024
13025
# File 'lib/google/apis/content_v2_1/classes.rb', line 13023

def store_config
  @store_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13030
13031
13032
13033
13034
13035
13036
13037
13038
13039
13040
13041
13042
13043
# File 'lib/google/apis/content_v2_1/classes.rb', line 13030

def update!(**args)
  @active = args[:active] if args.key?(:active)
  @currency = args[:currency] if args.key?(:currency)
  @delivery_country = args[:delivery_country] if args.key?(:delivery_country)
  @delivery_time = args[:delivery_time] if args.key?(:delivery_time)
  @eligibility = args[:eligibility] if args.key?(:eligibility)
  @minimum_order_value = args[:minimum_order_value] if args.key?(:minimum_order_value)
  @minimum_order_value_table = args[:minimum_order_value_table] if args.key?(:minimum_order_value_table)
  @name = args[:name] if args.key?(:name)
  @pickup_service = args[:pickup_service] if args.key?(:pickup_service)
  @rate_groups = args[:rate_groups] if args.key?(:rate_groups)
  @shipment_type = args[:shipment_type] if args.key?(:shipment_type)
  @store_config = args[:store_config] if args.key?(:store_config)
end