Class: Google::Apis::ContentV2_1::ServiceStoreConfigCutoffConfig
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::ServiceStoreConfigCutoffConfig
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
Time local delivery ends for the day based on the local timezone of the store.
local_cutoff_time and store_close_offset_hours are mutually exclusive.
Instance Attribute Summary collapse
-
#local_cutoff_time ⇒ Google::Apis::ContentV2_1::ServiceStoreConfigCutoffConfigLocalCutoffTime
Time in hours and minutes in the local timezone when local delivery ends.
-
#no_delivery_post_cutoff ⇒ Boolean
(also: #no_delivery_post_cutoff?)
Merchants can opt-out of showing n+1 day local delivery when they have a shipping service configured to n day local delivery.
-
#store_close_offset_hours ⇒ Fixnum
Represents cutoff time as the number of hours before store closing.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceStoreConfigCutoffConfig
constructor
A new instance of ServiceStoreConfigCutoffConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceStoreConfigCutoffConfig
Returns a new instance of ServiceStoreConfigCutoffConfig.
13115 13116 13117 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#local_cutoff_time ⇒ Google::Apis::ContentV2_1::ServiceStoreConfigCutoffConfigLocalCutoffTime
Time in hours and minutes in the local timezone when local delivery ends.
Corresponds to the JSON property localCutoffTime
13095 13096 13097 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13095 def local_cutoff_time @local_cutoff_time end |
#no_delivery_post_cutoff ⇒ Boolean Also known as: no_delivery_post_cutoff?
Merchants can opt-out of showing n+1 day local delivery when they have a
shipping service configured to n day local delivery. For example, if the
shipping service defines same-day delivery, and it's past the cut-off, setting
this field to true results in the calculated shipping service rate returning
NO_DELIVERY_POST_CUTOFF. In the same example, setting this field to false
results in the calculated shipping time being one day. This is only for local
delivery.
Corresponds to the JSON property noDeliveryPostCutoff
13106 13107 13108 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13106 def no_delivery_post_cutoff @no_delivery_post_cutoff end |
#store_close_offset_hours ⇒ Fixnum
Represents cutoff time as the number of hours before store closing. Mutually
exclusive with other fields (hour and minute).
Corresponds to the JSON property storeCloseOffsetHours
13113 13114 13115 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13113 def store_close_offset_hours @store_close_offset_hours end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13120 13121 13122 13123 13124 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13120 def update!(**args) @local_cutoff_time = args[:local_cutoff_time] if args.key?(:local_cutoff_time) @no_delivery_post_cutoff = args[:no_delivery_post_cutoff] if args.key?(:no_delivery_post_cutoff) @store_close_offset_hours = args[:store_close_offset_hours] if args.key?(:store_close_offset_hours) end |