Class: Google::Apis::ContentV2_1::ServiceStoreConfigCutoffConfigLocalCutoffTime
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::ServiceStoreConfigCutoffConfigLocalCutoffTime
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
Time in hours and minutes in the local timezone when local delivery ends.
Instance Attribute Summary collapse
-
#hour ⇒ Fixnum
Hour local delivery orders must be placed by to process the same day.
-
#minute ⇒ Fixnum
Minute local delivery orders must be placed by to process the same day.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceStoreConfigCutoffConfigLocalCutoffTime
constructor
A new instance of ServiceStoreConfigCutoffConfigLocalCutoffTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceStoreConfigCutoffConfigLocalCutoffTime
Returns a new instance of ServiceStoreConfigCutoffConfigLocalCutoffTime.
13141 13142 13143 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13141 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hour ⇒ Fixnum
Hour local delivery orders must be placed by to process the same day.
Corresponds to the JSON property hour
13134 13135 13136 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13134 def hour @hour end |
#minute ⇒ Fixnum
Minute local delivery orders must be placed by to process the same day.
Corresponds to the JSON property minute
13139 13140 13141 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13139 def minute @minute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13146 13147 13148 13149 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13146 def update!(**args) @hour = args[:hour] if args.key?(:hour) @minute = args[:minute] if args.key?(:minute) end |