Class: Google::Apis::ContentV2_1::ShippingSettings
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::ShippingSettings
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
The merchant account's shipping settings. All methods except getsupportedcarriers and getsupportedholidays require the admin role.
Instance Attribute Summary collapse
-
#account_id ⇒ Fixnum
The ID of the account to which these account shipping settings belong.
-
#postal_code_groups ⇒ Array<Google::Apis::ContentV2_1::PostalCodeGroup>
A list of postal code groups that can be referred to in
services. -
#services ⇒ Array<Google::Apis::ContentV2_1::Service>
The target account's list of services.
-
#warehouses ⇒ Array<Google::Apis::ContentV2_1::Warehouse>
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ShippingSettings
constructor
A new instance of ShippingSettings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ShippingSettings
Returns a new instance of ShippingSettings.
13178 13179 13180 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13178 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id ⇒ Fixnum
The ID of the account to which these account shipping settings belong. Ignored
upon update, always present in get request responses.
Corresponds to the JSON property accountId
13161 13162 13163 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13161 def account_id @account_id end |
#postal_code_groups ⇒ Array<Google::Apis::ContentV2_1::PostalCodeGroup>
A list of postal code groups that can be referred to in services. Optional.
Corresponds to the JSON property postalCodeGroups
13166 13167 13168 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13166 def postal_code_groups @postal_code_groups end |
#services ⇒ Array<Google::Apis::ContentV2_1::Service>
The target account's list of services. Optional.
Corresponds to the JSON property services
13171 13172 13173 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13171 def services @services end |
#warehouses ⇒ Array<Google::Apis::ContentV2_1::Warehouse>
Optional. A list of warehouses which can be referred to in services.
Corresponds to the JSON property warehouses
13176 13177 13178 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13176 def warehouses @warehouses end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
13183 13184 13185 13186 13187 13188 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 13183 def update!(**args) @account_id = args[:account_id] if args.key?(:account_id) @postal_code_groups = args[:postal_code_groups] if args.key?(:postal_code_groups) @services = args[:services] if args.key?(:services) @warehouses = args[:warehouses] if args.key?(:warehouses) end |