Class: Google::Apis::ContentV2_1::Table

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Table

Returns a new instance of Table.



13576
13577
13578
# File 'lib/google/apis/content_v2_1/classes.rb', line 13576

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#column_headersGoogle::Apis::ContentV2_1::Headers

A non-empty list of row or column headers for a table. Exactly one of prices, weights, numItems, postalCodeGroupNames, or location must be set. Corresponds to the JSON property columnHeaders



13557
13558
13559
# File 'lib/google/apis/content_v2_1/classes.rb', line 13557

def column_headers
  @column_headers
end

#nameString

Name of the table. Required for subtables, ignored for the main table. Corresponds to the JSON property name

Returns:

  • (String)


13562
13563
13564
# File 'lib/google/apis/content_v2_1/classes.rb', line 13562

def name
  @name
end

#row_headersGoogle::Apis::ContentV2_1::Headers

A non-empty list of row or column headers for a table. Exactly one of prices, weights, numItems, postalCodeGroupNames, or location must be set. Corresponds to the JSON property rowHeaders



13568
13569
13570
# File 'lib/google/apis/content_v2_1/classes.rb', line 13568

def row_headers
  @row_headers
end

#rowsArray<Google::Apis::ContentV2_1::Row>

The list of rows that constitute the table. Must have the same length as rowHeaders. Required. Corresponds to the JSON property rows

Returns:



13574
13575
13576
# File 'lib/google/apis/content_v2_1/classes.rb', line 13574

def rows
  @rows
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13581
13582
13583
13584
13585
13586
# File 'lib/google/apis/content_v2_1/classes.rb', line 13581

def update!(**args)
  @column_headers = args[:column_headers] if args.key?(:column_headers)
  @name = args[:name] if args.key?(:name)
  @row_headers = args[:row_headers] if args.key?(:row_headers)
  @rows = args[:rows] if args.key?(:rows)
end