Class: Google::Apis::ContentV2_1::TriggerActionPayload

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb

Overview

The payload for the triggered action.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TriggerActionPayload

Returns a new instance of TriggerActionPayload.



13859
13860
13861
# File 'lib/google/apis/content_v2_1/classes.rb', line 13859

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#action_contextString

Required. The context from the selected action. The value is obtained from rendered issues and needs to be sent back to identify the action that is being triggered. Corresponds to the JSON property actionContext

Returns:

  • (String)


13852
13853
13854
# File 'lib/google/apis/content_v2_1/classes.rb', line 13852

def action_context
  @action_context
end

#action_inputGoogle::Apis::ContentV2_1::ActionInput

Input provided by the merchant. Corresponds to the JSON property actionInput



13857
13858
13859
# File 'lib/google/apis/content_v2_1/classes.rb', line 13857

def action_input
  @action_input
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13864
13865
13866
13867
# File 'lib/google/apis/content_v2_1/classes.rb', line 13864

def update!(**args)
  @action_context = args[:action_context] if args.key?(:action_context)
  @action_input = args[:action_input] if args.key?(:action_input)
end