Class: Google::Apis::ContentV2_1::UrlSettings

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb

Overview

Specifications related to the Checkout URL. The UriTemplate is of the form https://www.mystore.com/checkout?item_id=idwhereid`` will be automatically replaced with data from the merchant account with this attribute offer_id

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ UrlSettings

Returns a new instance of UrlSettings.



13922
13923
13924
# File 'lib/google/apis/content_v2_1/classes.rb', line 13922

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cart_uri_templateString

URL template when the placeholders are expanded will redirect the buyer to the cart page on the merchant website with the selected item in cart. Corresponds to the JSON property cartUriTemplate

Returns:

  • (String)


13914
13915
13916
# File 'lib/google/apis/content_v2_1/classes.rb', line 13914

def cart_uri_template
  @cart_uri_template
end

#checkout_uri_templateString

URL template when the placeholders are expanded will redirect the buyer to the merchant checkout page with the item in the cart. Corresponds to the JSON property checkoutUriTemplate

Returns:

  • (String)


13920
13921
13922
# File 'lib/google/apis/content_v2_1/classes.rb', line 13920

def checkout_uri_template
  @checkout_uri_template
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



13927
13928
13929
13930
# File 'lib/google/apis/content_v2_1/classes.rb', line 13927

def update!(**args)
  @cart_uri_template = args[:cart_uri_template] if args.key?(:cart_uri_template)
  @checkout_uri_template = args[:checkout_uri_template] if args.key?(:checkout_uri_template)
end