Class: Google::Apis::ContentV2_1::WarehouseBasedDeliveryTime

Inherits:
Object
  • Object
show all
Includes:
Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
Defined in:
lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WarehouseBasedDeliveryTime

Returns a new instance of WarehouseBasedDeliveryTime.



14133
14134
14135
# File 'lib/google/apis/content_v2_1/classes.rb', line 14133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#carrierString

Required. Carrier, such as "UPS" or "Fedex". The list of supported carriers can be retrieved through the listSupportedCarriers method. Corresponds to the JSON property carrier

Returns:

  • (String)


14090
14091
14092
# File 'lib/google/apis/content_v2_1/classes.rb', line 14090

def carrier
  @carrier
end

#carrier_serviceString

Required. Carrier service, such as "ground" or "2 days". The list of supported services for a carrier can be retrieved through the listSupportedCarriers method. The name of the service must be in the eddSupportedServices list. Corresponds to the JSON property carrierService

Returns:

  • (String)


14098
14099
14100
# File 'lib/google/apis/content_v2_1/classes.rb', line 14098

def carrier_service
  @carrier_service
end

#origin_administrative_areaString

Shipping origin's state. Corresponds to the JSON property originAdministrativeArea

Returns:

  • (String)


14103
14104
14105
# File 'lib/google/apis/content_v2_1/classes.rb', line 14103

def origin_administrative_area
  @origin_administrative_area
end

#origin_cityString

Shipping origin's city. Corresponds to the JSON property originCity

Returns:

  • (String)


14108
14109
14110
# File 'lib/google/apis/content_v2_1/classes.rb', line 14108

def origin_city
  @origin_city
end

#origin_countryString

Shipping origin's country represented as a CLDR territory code. Corresponds to the JSON property originCountry

Returns:

  • (String)


14114
14115
14116
# File 'lib/google/apis/content_v2_1/classes.rb', line 14114

def origin_country
  @origin_country
end

#origin_postal_codeString

Shipping origin. Corresponds to the JSON property originPostalCode

Returns:

  • (String)


14119
14120
14121
# File 'lib/google/apis/content_v2_1/classes.rb', line 14119

def origin_postal_code
  @origin_postal_code
end

#origin_street_addressString

Shipping origin's street address. Corresponds to the JSON property originStreetAddress

Returns:

  • (String)


14124
14125
14126
# File 'lib/google/apis/content_v2_1/classes.rb', line 14124

def origin_street_address
  @origin_street_address
end

#warehouse_nameString

The name of the warehouse. Warehouse name need to be matched with name. If warehouseName is set, the below fields will be ignored. The warehouse info will be read from warehouse. Corresponds to the JSON property warehouseName

Returns:

  • (String)


14131
14132
14133
# File 'lib/google/apis/content_v2_1/classes.rb', line 14131

def warehouse_name
  @warehouse_name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



14138
14139
14140
14141
14142
14143
14144
14145
14146
14147
# File 'lib/google/apis/content_v2_1/classes.rb', line 14138

def update!(**args)
  @carrier = args[:carrier] if args.key?(:carrier)
  @carrier_service = args[:carrier_service] if args.key?(:carrier_service)
  @origin_administrative_area = args[:origin_administrative_area] if args.key?(:origin_administrative_area)
  @origin_city = args[:origin_city] if args.key?(:origin_city)
  @origin_country = args[:origin_country] if args.key?(:origin_country)
  @origin_postal_code = args[:origin_postal_code] if args.key?(:origin_postal_code)
  @origin_street_address = args[:origin_street_address] if args.key?(:origin_street_address)
  @warehouse_name = args[:warehouse_name] if args.key?(:warehouse_name)
end