Class: Google::Apis::ContentV2_1::ProductView
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::ProductView
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
Product fields. Values are only set for fields requested explicitly in the request's search query.
Instance Attribute Summary collapse
-
#aggregated_destination_status ⇒ String
Aggregated destination status.
-
#availability ⇒ String
Availability of the product.
-
#brand ⇒ String
Brand of the product.
-
#category_l1 ⇒ String
First level of the product category in Google's product taxonomy.
-
#category_l2 ⇒ String
Second level of the product category in Google's product taxonomy.
-
#category_l3 ⇒ String
Third level of the product category in Google's product taxonomy.
-
#category_l4 ⇒ String
Fourth level of the product category in Google's product taxonomy.
-
#category_l5 ⇒ String
Fifth level of the product category in Google's product taxonomy.
-
#channel ⇒ String
Channel of the product (online versus local).
-
#click_potential ⇒ String
Estimated performance potential compared to highest performing products of the merchant.
-
#click_potential_rank ⇒ Fixnum
Normalized click potential of the product.
-
#condition ⇒ String
Condition of the product.
-
#creation_time ⇒ String
The time the merchant created the product in timestamp seconds.
-
#currency_code ⇒ String
Product price currency code (for example, ISO 4217).
-
#expiration_date ⇒ Google::Apis::ContentV2_1::Date
Represents a whole or partial calendar date, such as a birthday.
-
#gtin ⇒ Array<String>
GTIN of the product.
-
#id ⇒ String
The REST ID of the product, in the form of channel:contentLanguage: targetCountry:offerId.
-
#item_group_id ⇒ String
Item group ID provided by the merchant for grouping variants together.
-
#item_issues ⇒ Array<Google::Apis::ContentV2_1::ProductViewItemIssue>
List of item issues for the product.
-
#language_code ⇒ String
Language code of the product in BCP 47 format.
-
#offer_id ⇒ String
Merchant-provided id of the product.
-
#price_micros ⇒ Fixnum
Product price specified as micros (1 millionth of a standard unit, 1 USD = 1000000 micros) in the product currency.
-
#product_type_l1 ⇒ String
First level of the product type in merchant's own product taxonomy.
-
#product_type_l2 ⇒ String
Second level of the product type in merchant's own product taxonomy.
-
#product_type_l3 ⇒ String
Third level of the product type in merchant's own product taxonomy.
-
#product_type_l4 ⇒ String
Fourth level of the product type in merchant's own product taxonomy.
-
#product_type_l5 ⇒ String
Fifth level of the product type in merchant's own product taxonomy.
-
#shipping_label ⇒ String
The normalized shipping label specified in the feed Corresponds to the JSON property
shippingLabel. -
#title ⇒ String
Title of the product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductView
constructor
A new instance of ProductView.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductView
Returns a new instance of ProductView.
10572 10573 10574 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10572 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aggregated_destination_status ⇒ String
Aggregated destination status.
Corresponds to the JSON property aggregatedDestinationStatus
10406 10407 10408 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10406 def aggregated_destination_status @aggregated_destination_status end |
#availability ⇒ String
Availability of the product.
Corresponds to the JSON property availability
10411 10412 10413 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10411 def availability @availability end |
#brand ⇒ String
Brand of the product.
Corresponds to the JSON property brand
10416 10417 10418 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10416 def brand @brand end |
#category_l1 ⇒ String
First level of the product category in Google's product taxonomy.
Corresponds to the JSON property categoryL1
10422 10423 10424 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10422 def category_l1 @category_l1 end |
#category_l2 ⇒ String
Second level of the product category in Google's product taxonomy.
Corresponds to the JSON property categoryL2
10428 10429 10430 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10428 def category_l2 @category_l2 end |
#category_l3 ⇒ String
Third level of the product category in Google's product taxonomy.
Corresponds to the JSON property categoryL3
10434 10435 10436 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10434 def category_l3 @category_l3 end |
#category_l4 ⇒ String
Fourth level of the product category in Google's product taxonomy.
Corresponds to the JSON property categoryL4
10440 10441 10442 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10440 def category_l4 @category_l4 end |
#category_l5 ⇒ String
Fifth level of the product category in Google's product taxonomy.
Corresponds to the JSON property categoryL5
10446 10447 10448 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10446 def category_l5 @category_l5 end |
#channel ⇒ String
Channel of the product (online versus local).
Corresponds to the JSON property channel
10451 10452 10453 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10451 def channel @channel end |
#click_potential ⇒ String
Estimated performance potential compared to highest performing products of the
merchant.
Corresponds to the JSON property clickPotential
10457 10458 10459 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10457 def click_potential @click_potential end |
#click_potential_rank ⇒ Fixnum
Normalized click potential of the product. Values range from 1 to 1000, where
1 is the highest click potential and 1000 is the theoretical lowest.
Corresponds to the JSON property clickPotentialRank
10463 10464 10465 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10463 def click_potential_rank @click_potential_rank end |
#condition ⇒ String
Condition of the product.
Corresponds to the JSON property condition
10468 10469 10470 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10468 def condition @condition end |
#creation_time ⇒ String
The time the merchant created the product in timestamp seconds.
Corresponds to the JSON property creationTime
10473 10474 10475 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10473 def creation_time @creation_time end |
#currency_code ⇒ String
Product price currency code (for example, ISO 4217). Absent if product price
is not available.
Corresponds to the JSON property currencyCode
10479 10480 10481 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10479 def currency_code @currency_code end |
#expiration_date ⇒ Google::Apis::ContentV2_1::Date
Represents a whole or partial calendar date, such as a birthday. The time of
day and time zone are either specified elsewhere or are insignificant. The
date is relative to the Gregorian Calendar. This can represent one of the
following: * A full date, with non-zero year, month, and day values. * A month
and day, with a zero year (for example, an anniversary). * A year on its own,
with a zero month and a zero day. * A year and month, with a zero day (for
example, a credit card expiration date). Related types: * google.type.
TimeOfDay * google.type.DateTime * google.protobuf.Timestamp
Corresponds to the JSON property expirationDate
10491 10492 10493 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10491 def expiration_date @expiration_date end |
#gtin ⇒ Array<String>
GTIN of the product.
Corresponds to the JSON property gtin
10496 10497 10498 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10496 def gtin @gtin end |
#id ⇒ String
The REST ID of the product, in the form of channel:contentLanguage:
targetCountry:offerId. Content API methods that operate on products take this
as their productId parameter. Should always be included in the SELECT clause.
Corresponds to the JSON property id
10503 10504 10505 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10503 def id @id end |
#item_group_id ⇒ String
Item group ID provided by the merchant for grouping variants together.
Corresponds to the JSON property itemGroupId
10508 10509 10510 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10508 def item_group_id @item_group_id end |
#item_issues ⇒ Array<Google::Apis::ContentV2_1::ProductViewItemIssue>
List of item issues for the product.
Corresponds to the JSON property itemIssues
10513 10514 10515 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10513 def item_issues @item_issues end |
#language_code ⇒ String
Language code of the product in BCP 47 format.
Corresponds to the JSON property languageCode
10518 10519 10520 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10518 def language_code @language_code end |
#offer_id ⇒ String
Merchant-provided id of the product.
Corresponds to the JSON property offerId
10523 10524 10525 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10523 def offer_id @offer_id end |
#price_micros ⇒ Fixnum
Product price specified as micros (1 millionth of a standard unit, 1 USD =
1000000 micros) in the product currency. Absent in case the information about
the price of the product is not available.
Corresponds to the JSON property priceMicros
10530 10531 10532 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10530 def price_micros @price_micros end |
#product_type_l1 ⇒ String
First level of the product type in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL1
10536 10537 10538 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10536 def product_type_l1 @product_type_l1 end |
#product_type_l2 ⇒ String
Second level of the product type in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL2
10542 10543 10544 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10542 def product_type_l2 @product_type_l2 end |
#product_type_l3 ⇒ String
Third level of the product type in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL3
10548 10549 10550 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10548 def product_type_l3 @product_type_l3 end |
#product_type_l4 ⇒ String
Fourth level of the product type in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL4
10554 10555 10556 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10554 def product_type_l4 @product_type_l4 end |
#product_type_l5 ⇒ String
Fifth level of the product type in merchant's own product taxonomy.
Corresponds to the JSON property productTypeL5
10560 10561 10562 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10560 def product_type_l5 @product_type_l5 end |
#shipping_label ⇒ String
The normalized shipping label specified in the feed
Corresponds to the JSON property shippingLabel
10565 10566 10567 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10565 def shipping_label @shipping_label end |
#title ⇒ String
Title of the product.
Corresponds to the JSON property title
10570 10571 10572 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10570 def title @title end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10577 10578 10579 10580 10581 10582 10583 10584 10585 10586 10587 10588 10589 10590 10591 10592 10593 10594 10595 10596 10597 10598 10599 10600 10601 10602 10603 10604 10605 10606 10607 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10577 def update!(**args) @aggregated_destination_status = args[:aggregated_destination_status] if args.key?(:aggregated_destination_status) @availability = args[:availability] if args.key?(:availability) @brand = args[:brand] if args.key?(:brand) @category_l1 = args[:category_l1] if args.key?(:category_l1) @category_l2 = args[:category_l2] if args.key?(:category_l2) @category_l3 = args[:category_l3] if args.key?(:category_l3) @category_l4 = args[:category_l4] if args.key?(:category_l4) @category_l5 = args[:category_l5] if args.key?(:category_l5) @channel = args[:channel] if args.key?(:channel) @click_potential = args[:click_potential] if args.key?(:click_potential) @click_potential_rank = args[:click_potential_rank] if args.key?(:click_potential_rank) @condition = args[:condition] if args.key?(:condition) @creation_time = args[:creation_time] if args.key?(:creation_time) @currency_code = args[:currency_code] if args.key?(:currency_code) @expiration_date = args[:expiration_date] if args.key?(:expiration_date) @gtin = args[:gtin] if args.key?(:gtin) @id = args[:id] if args.key?(:id) @item_group_id = args[:item_group_id] if args.key?(:item_group_id) @item_issues = args[:item_issues] if args.key?(:item_issues) @language_code = args[:language_code] if args.key?(:language_code) @offer_id = args[:offer_id] if args.key?(:offer_id) @price_micros = args[:price_micros] if args.key?(:price_micros) @product_type_l1 = args[:product_type_l1] if args.key?(:product_type_l1) @product_type_l2 = args[:product_type_l2] if args.key?(:product_type_l2) @product_type_l3 = args[:product_type_l3] if args.key?(:product_type_l3) @product_type_l4 = args[:product_type_l4] if args.key?(:product_type_l4) @product_type_l5 = args[:product_type_l5] if args.key?(:product_type_l5) @shipping_label = args[:shipping_label] if args.key?(:shipping_label) @title = args[:title] if args.key?(:title) end |