Class: Google::Apis::ContentV2_1::ProductsCustomBatchResponseEntry
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::ProductsCustomBatchResponseEntry
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
A batch entry encoding a single non-batch products response.
Instance Attribute Summary collapse
-
#batch_id ⇒ Fixnum
The ID of the request entry this entry responds to.
-
#errors ⇒ Google::Apis::ContentV2_1::Errors
A list of errors returned by a failed batch entry.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#product ⇒ Google::Apis::ContentV2_1::Product
Required product attributes are primarily defined by the product data specification.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProductsCustomBatchResponseEntry
constructor
A new instance of ProductsCustomBatchResponseEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProductsCustomBatchResponseEntry
Returns a new instance of ProductsCustomBatchResponseEntry.
10894 10895 10896 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10894 def initialize(**args) update!(**args) end |
Instance Attribute Details
#batch_id ⇒ Fixnum
The ID of the request entry this entry responds to.
Corresponds to the JSON property batchId
10870 10871 10872 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10870 def batch_id @batch_id end |
#errors ⇒ Google::Apis::ContentV2_1::Errors
A list of errors returned by a failed batch entry.
Corresponds to the JSON property errors
10875 10876 10877 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10875 def errors @errors end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "content#
productsCustomBatchResponseEntry"
Corresponds to the JSON property kind
10881 10882 10883 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10881 def kind @kind end |
#product ⇒ Google::Apis::ContentV2_1::Product
Required product attributes are primarily defined by the product data
specification. See the Product Data Specification Help Center article for
information. Product data. After inserting, updating, or deleting a product,
it may take several minutes before changes take effect. The following
reference documentation lists the field names in the camelCase casing
style while the Products Data Specification lists the names in the **
snake_case** casing style.
Corresponds to the JSON property product
10892 10893 10894 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10892 def product @product end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
10899 10900 10901 10902 10903 10904 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 10899 def update!(**args) @batch_id = args[:batch_id] if args.key?(:batch_id) @errors = args[:errors] if args.key?(:errors) @kind = args[:kind] if args.key?(:kind) @product = args[:product] if args.key?(:product) end |