Class: Google::Apis::ContentV2_1::RenderAccountIssuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::RenderAccountIssuesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
Response containing support content and actions for listed account issues.
Instance Attribute Summary collapse
-
#alternate_dispute_resolution ⇒ Google::Apis::ContentV2_1::AlternateDisputeResolution
The Alternate Dispute Resolution (ADR) that may be available to merchants in some regions.
-
#issues ⇒ Array<Google::Apis::ContentV2_1::AccountIssue>
List of account issues for a given account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RenderAccountIssuesResponse
constructor
A new instance of RenderAccountIssuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RenderAccountIssuesResponse
Returns a new instance of RenderAccountIssuesResponse.
12164 12165 12166 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12164 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_dispute_resolution ⇒ Google::Apis::ContentV2_1::AlternateDisputeResolution
The Alternate Dispute Resolution (ADR) that may be available to merchants in
some regions. If present, the link should be shown on the same page as the
list of issues.
Corresponds to the JSON property alternateDisputeResolution
12154 12155 12156 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12154 def alternate_dispute_resolution @alternate_dispute_resolution end |
#issues ⇒ Array<Google::Apis::ContentV2_1::AccountIssue>
List of account issues for a given account. This list can be shown with
compressed, expandable items. In the compressed form, the title and impact
should be shown for each issue. Once the issue is expanded, the detailed
content and available actions should be rendered.
Corresponds to the JSON property issues
12162 12163 12164 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12162 def issues @issues end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12169 12170 12171 12172 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12169 def update!(**args) @alternate_dispute_resolution = args[:alternate_dispute_resolution] if args.key?(:alternate_dispute_resolution) @issues = args[:issues] if args.key?(:issues) end |