Class: Google::Apis::ContentV2_1::RenderProductIssuesResponse
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::RenderProductIssuesResponse
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
Response containing support content and actions for listed product issues.
Instance Attribute Summary collapse
-
#alternate_dispute_resolution ⇒ Google::Apis::ContentV2_1::AlternateDisputeResolution
The Alternate Dispute Resolution (ADR) that may be available to merchants in some regions.
-
#issues ⇒ Array<Google::Apis::ContentV2_1::ProductIssue>
List of issues for a given product.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RenderProductIssuesResponse
constructor
A new instance of RenderProductIssuesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RenderProductIssuesResponse
Returns a new instance of RenderProductIssuesResponse.
12222 12223 12224 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12222 def initialize(**args) update!(**args) end |
Instance Attribute Details
#alternate_dispute_resolution ⇒ Google::Apis::ContentV2_1::AlternateDisputeResolution
The Alternate Dispute Resolution (ADR) that may be available to merchants in
some regions. If present, the link should be shown on the same page as the
list of issues.
Corresponds to the JSON property alternateDisputeResolution
12212 12213 12214 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12212 def alternate_dispute_resolution @alternate_dispute_resolution end |
#issues ⇒ Array<Google::Apis::ContentV2_1::ProductIssue>
List of issues for a given product. This list can be shown with compressed,
expandable items. In the compressed form, the title and impact should be shown
for each issue. Once the issue is expanded, the detailed content and available
actions should be rendered.
Corresponds to the JSON property issues
12220 12221 12222 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12220 def issues @issues end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12227 12228 12229 12230 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12227 def update!(**args) @alternate_dispute_resolution = args[:alternate_dispute_resolution] if args.key?(:alternate_dispute_resolution) @issues = args[:issues] if args.key?(:issues) end |