Class: Google::Apis::ContentV2_1::SearchRequest
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::SearchRequest
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Overview
Request message for the ReportService.Search method.
Instance Attribute Summary collapse
-
#page_size ⇒ Fixnum
Number of ReportRows to retrieve in a single page.
-
#page_token ⇒ String
Token of the page to retrieve.
-
#query ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SearchRequest
constructor
A new instance of SearchRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SearchRequest
Returns a new instance of SearchRequest.
12715 12716 12717 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12715 def initialize(**args) update!(**args) end |
Instance Attribute Details
#page_size ⇒ Fixnum
Number of ReportRows to retrieve in a single page. Defaults to 1000. Values
above 5000 are coerced to 5000.
Corresponds to the JSON property pageSize
12698 12699 12700 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12698 def page_size @page_size end |
#page_token ⇒ String
Token of the page to retrieve. If not specified, the first page of results is
returned. In order to request the next page of results, the value obtained
from next_page_token in the previous response should be used.
Corresponds to the JSON property pageToken
12705 12706 12707 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12705 def page_token @page_token end |
#query ⇒ String
Required. Query that defines performance metrics to retrieve and dimensions
according to which the metrics are to be segmented. For details on how to
construct your query, see the Query Language guide.
Corresponds to the JSON property query
12713 12714 12715 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12713 def query @query end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
12720 12721 12722 12723 12724 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 12720 def update!(**args) @page_size = args[:page_size] if args.key?(:page_size) @page_token = args[:page_token] if args.key?(:page_token) @query = args[:query] if args.key?(:query) end |