Class: Google::Apis::ContentV2_1::WarehouseCutoffTime
- Inherits:
-
Object
- Object
- Google::Apis::ContentV2_1::WarehouseCutoffTime
- Includes:
- Google::Apis::Core::Hashable, Google::Apis::Core::JsonObjectSupport
- Defined in:
- lib/google/apis/content_v2_1/classes.rb,
lib/google/apis/content_v2_1/representations.rb,
lib/google/apis/content_v2_1/representations.rb
Instance Attribute Summary collapse
-
#hour ⇒ Fixnum
Required.
-
#minute ⇒ Fixnum
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WarehouseCutoffTime
constructor
A new instance of WarehouseCutoffTime.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WarehouseCutoffTime
Returns a new instance of WarehouseCutoffTime.
14168 14169 14170 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 14168 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hour ⇒ Fixnum
Required. Hour (24-hour clock) of the cutoff time until which an order has to
be placed to be processed in the same day by the warehouse. Hour is based on
the timezone of warehouse.
Corresponds to the JSON property hour
14159 14160 14161 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 14159 def hour @hour end |
#minute ⇒ Fixnum
Required. Minute of the cutoff time until which an order has to be placed to
be processed in the same day by the warehouse. Minute is based on the timezone
of warehouse.
Corresponds to the JSON property minute
14166 14167 14168 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 14166 def minute @minute end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
14173 14174 14175 14176 |
# File 'lib/google/apis/content_v2_1/classes.rb', line 14173 def update!(**args) @hour = args[:hour] if args.key?(:hour) @minute = args[:minute] if args.key?(:minute) end |